@@ -1,5 +1,4 @@
 from cyberfusion.CoreApiClient import models
-from typing import Optional, List
 
 from cyberfusion.CoreApiClient.http import DtoResponse
 from cyberfusion.CoreApiClient.interfaces import Resource
@@ -24,21 +23,21 @@ class DatabaseUserGrants(Resource):
     def list_database_user_grants(
         self,
         *,
-        skip: Optional[int] = None,
-        limit: Optional[int] = None,
-        filter_: Optional[List[str]] = None,
-        sort: Optional[List[str]] = None,
+        page: int = 1,
+        per_page: int = 0,
+        include_filters: models.DatabaseUserGrantsSearchRequest | None = None,
     ) -> DtoResponse[list[models.DatabaseUserGrantResource]]:
         local_response = self.api_connector.send_or_fail(
             "GET",
             "/api/v1/database-user-grants",
             data=None,
             query_parameters={
-                "skip": skip,
-                "limit": limit,
-                "filter": filter_,
-                "sort": sort,
-            },
+                "page": page,
+                "per_page": per_page,
+            }
+            | include_filters.dict(exclude_unset=True)
+            if include_filters
+            else None,
         )
 
         return DtoResponse.from_response(
